@@ -271,9 +271,11 @@ int main(int argc, char* argv[])
             saphire_set_signal();
             saphire_init(kATConsoleApp, FALSE, runtime_script);
             sWFd* pipeout = sWFd_new(STDOUT_FILENO);
-            int rcode = saphire_load(file_name, pipeout, STDIN_FILENO, STDERR_FILENO);
+            sRFd* pipein = sRFd_new(STDIN_FILENO);
+            int rcode = saphire_load(file_name, pipeout, pipein, STDERR_FILENO);
             sWFd_flash(pipeout);
             sWFd_delete(pipeout);
+            sRFd_delete(pipein);
             if(rcode != 0) {
                 fprintf(stderr, "run time err\n");
                 fprintf(stderr, "%s", string_c_str(gErrMsg));
