@@ -38,6 +38,7 @@ typedef struct {
 } sRFd;
 
 sRFd* sRFd_new(int fd);
+sRFd* sRFd_new2(int fd, char* str);
 void sRFd_delete(sRFd* self);
 BOOL sRFd_close(sRFd* self);
 int sRFd_read_all(sRFd* self, string_obj* str);
@@ -117,6 +118,9 @@ int saphire_load(char* fname, sWFd* pipeout, sRFd* pipein, int pipeerr);
     // verboseは実行しているコマンド名を表示するかどうか
 BOOL saphire_compile(char* fname, char* out_fname);
     // fnameのファイルをコンパイルしてout_fnameに保存
+    // スクリプトファイルを読み込んでコンパイルして
+    // ファイルとして書き込む関数。
+    // エラー時はgErrMsgにエラーメッセージが入っている
 int saphire_load_obj(char* fname, sWFd* pipeout, sRFd* pipein, int pipeerr);
     // コンパイル済みのファイルfnameを実行
     // pipeoutは出力先。pipeinは入力先
@@ -220,6 +224,8 @@ BOOL saphire_compile2(char* cmdline, char* fname, sStatments* statments);
     // statmentsはsStatments_newによって初期化されないといけない。
     // また必要でなくなったらsStatments_deleteによって開放しないといけない。
     // 終了時にできればsStatments_deleteしたほうがよい。
+    // エラー時はgErrMsgにエラー内容が入っている
+int saphire_run(sStatments* statments, char* title, sWFd* pipeout, sRFd* pipein, int pipeerr);
 
     // サンプル
     /*
@@ -234,6 +240,23 @@ BOOL saphire_compile2(char* cmdline, char* fname, sStatments* statments);
 
     */
 
+// 出力をCTRL-Cで止めたいので、この関数を経由して書き込む
+// 戻り値 FALSE --> CTRL-Cで止められた
+// 戻り値 TRUE --> 正常終了
+BOOL statment_tree_internal_commands_write_nextout(sWFd* nextout, char* str);
+
+// 出力をCTRL-Cで止めたいので、この関数を経由して読み込む
+// 戻り値 -1 --> CTRL-Cで止められた
+// 戻り値 0 --> 正常終了
+// 戻り値 1 --> EOF
+int statment_tree_internal_commands_read_nextin(sRFd* nextin, string_obj* str);
+
+// 出力をCTRL-Cで止めたいので、この関数を経由して読み込む
+// 戻り値 -1 --> CTRL-Cで止められた
+// 戻り値 0 --> 正常終了
+// 戻り値 1 --> EOF
+int statment_tree_internal_commands_read_nextin_oneline(sRFd* nextin, string_obj* str);
+
 
 #endif
 
