@@ -53,8 +53,8 @@ char* gStatmentKindStrs[kCommand+1] = {
     "x", "join", "lines", "rows",
     "ary_new", "ary_add", "ary_erase", "ary_clear", 
     "hash_new", "hash_add", "hash_erase", "hash_clear",
-    "match", "pos", "sub",  
-    "scan", "read",
+    "match", "scan", "erase", "pos", "sub",  
+    "read",
     "cd", 
     "add", "del",  "selector", "max", "min", "extname", 
     "parentname", "noextname", 
@@ -315,8 +315,7 @@ void clear_ary_env(char* key)
 void err_msg(char* msg)
 {
     char* tmp = MALLOC(string_length(gFName) + 128 + strlen(msg));
-    snprintf(tmp, string_length(gFName) + 128 + strlen(msg), "%s %d: %s\n", string_c_str(gFName)
-                , gLine, msg);
+    snprintf(tmp, string_length(gFName) + 128 + strlen(msg), "%s %d: %s\n", string_c_str(gFName) , gLine, msg);
 
     string_put(gErrMsg, tmp);
 
@@ -599,6 +598,14 @@ void sig_int()
 fprintf(stderr, "SIGINT!!\n");
 #endif
 }
+void sig_tstp()
+{
+    gKitutukiSigInt = TRUE; 
+//printf("gKitutukiSigInt %d %p\n", gKitutukiSigInt, &gKitutukiSigInt);
+#ifdef MDEBUG
+fprintf(stderr, "SIGTSTP!!\n");
+#endif
+}
 
 void sig_user()
 {
@@ -745,7 +752,7 @@ void saphire_set_signal()
     }
 
     memset(&sa, 0, sizeof(sa));
-    sa.sa_handler = SIG_IGN;
+    sa.sa_handler = sig_tstp;
     sa.sa_flags = 0;
     if(sigaction(SIGTSTP, &sa, NULL) < 0) {
         perror("sigaction7");
@@ -961,6 +968,14 @@ void sArg_delete(sArg* self)
     case 2:
         sStatments_delete(self->mBody);
         break;
+
+    case 3:
+        sVar_delete(self->mBody);
+        break;
+
+    case 4:
+        sStatments_delete(self->mBody);
+        break;
     }
 
     FREE(self);
@@ -1075,6 +1090,14 @@ void sArgTmp_delete(sArgTmp* self)
     case 3:
         if(self->mBody) sStatments_delete(self->mBody);
         break;
+
+    case 4:
+        if(self->mBody) sVar_delete(self->mBody);
+        break;
+
+    case 5:
+        if(self->mBody) sStatments_delete(self->mBody);
+        break;
     }
 
     FREE(self);
@@ -2002,12 +2025,13 @@ void sOtherCProg_delete(sOtherCProg* self)
 ///////////////////////////////////////////////////////
 // 子プロセス
 ///////////////////////////////////////////////////////
-sChildProgram* sChildProgram_new(pid_t pid, char* title)
+sChildProgram* sChildProgram_new(pid_t pid, char* title, BOOL writer_process)
 {
     sChildProgram* self = (sChildProgram*)MALLOC(sizeof(sChildProgram));
 
     self->mPid = pid;
     self->mTitle = STRING_NEW(title);
+    self->mWriterProcess = writer_process;
 
     return self;
 }
@@ -2304,7 +2328,7 @@ void saphire_init(enum eAppType app_type, BOOL job_control, enum eRuntimeScript
 
     gFileHandles = HASH_NEW(100);
 
-    setenv("SAPHIRE_VERSION", "0.9.1", 1);
+    setenv("SAPHIRE_VERSION", "0.9.2", 1);
     setenv("SAPHIRE_PROMPT", "> ", 1);
     setenv("SAPHIRE_DOCDIR", DOCDIR, 1);
     char* home = getenv("HOME");
@@ -2554,6 +2578,16 @@ sRFd* sRFd_new(int fd)
     return self;
 }
 
+sRFd* sRFd_new2(int fd, char* str)
+{
+    sRFd* self = (sRFd*)MALLOC(sizeof(sRFd));
+
+    self->mBuffer = STRING_NEW(str);
+    self->mFd = fd;
+
+    return self;
+}
+
 void sRFd_delete(sRFd* self)
 {
     string_delete(self->mBuffer);
